@@ -21,7 +21,7 @@ require AutoLoader;
 @EXPORT = qw(
 	
 );
-$VERSION = '2.01';
+$VERSION = '2.02';
 
 my %EuroRates = (
          BEF => {EUR=>0.0247899055505,   BEF => 1},
@@ -50,12 +50,14 @@ my %EuroRates = (
 
 sub new() {
 	my $proto = shift;
+	my $ratesFile = shift; # optional
 	my $class = ref($proto) || $proto;
 	my $self = {};
 	$self->{CurrencyRates} = \%EuroRates;
-	$self->{RatesFile} = undef;
+	$self->{RatesFile} = $ratesFile;
 	$self->{UserAgent} = "Finance::Currency::Convert $VERSION";
 	bless($self, $class);
+	$self->readRatesFile() if (defined($ratesFile));
 	return $self;
 }
 
@@ -70,6 +72,7 @@ sub setRate() {
 sub setRatesFile() {
 	my $self = shift;
 	$self->{RatesFile} = shift;
+	$self->readRatesFile();
 }
 
 sub readRatesFile() {
@@ -100,10 +103,13 @@ sub writeRatesFile() {
 	foreach my $sourcerate (sort keys %{$self->{CurrencyRates}}) {
 		print RATES "$sourcerate|";
 		foreach my $targetrate (sort keys %{ $self->{CurrencyRates}{$sourcerate}}) {
-			print RATES "$targetrate=" . $self->{CurrencyRates}{$sourcerate}{$targetrate} . ":";
-		};
+			if (exists($self->{CurrencyRates}{$sourcerate}{$targetrate})
+				&& $self->{CurrencyRates}{$sourcerate}{$targetrate} ne '') {
+				print RATES "$targetrate=" . $self->{CurrencyRates}{$sourcerate}{$targetrate} . ":";
+			}
+		}
 		print RATES "\n";
-	};
+	}
 	close(RATES);
 }
 
